/*****************************************************************************
 *
 *  AngleListParameter.cc                       XMM Science Analysis Subsystem
 *
 *  Angle-std::list task parameter
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AngleListParameter.cc,v 1.6 2002/12/17 17:53:48 jbakker Exp $
 *
 *****************************************************************************/

#include "AngleListParameter.h"
#include "Xmm.h"
#include "QuotedString.h" // utils

#include <iostream>


//================================================================
//  Class AngleListParameter
//================================================================

/*** Constructor ***/

AngleListParameter::AngleListParameter()
{
    _mode = AngleFormatter::Degrees;
}


/*** Set the format mode ***/

void AngleListParameter::setMode(AngleFormatter::AngleMode mode)
{
    if (_mode == mode) return;
    _mode = mode;
    notifyView();
}


/*** Format a single element as a std::string ***/

std::string AngleListParameter::doubleAsString(double value) const
{
    AngleFormatter t(_mode);

    return QuotedString(t.asString(value));
}


/*** Parse a single std::list element ***/

bool AngleListParameter::parseDouble(const std::string& s, double& result, bool first)
{
    AngleFormatter t;
    bool ok = t.parse(s, result);

    if(ok && first)                // Base mode on first element
        _mode = t.mode();

    return ok;
}
