/*****************************************************************************
 *
 *  IntListParameter.h                          XMM Science Analysis Subsystem
 *
 *  Integer-std::list task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: IntListParameter.h,v 1.11 2002/12/17 17:53:49 jbakker Exp $
 *
 *****************************************************************************/

#ifndef INTLISTPARAMETER_H
#define INTLISTPARAMETER_H

#include "Parameter.h"

#include <string>                // C++ headers
#include <vector>


//================================================================
//  Class IntListParameter
//================================================================

class IntListParameter : public Parameter
{
public:
    // Construction
    IntListParameter* clone() { return new IntListParameter(*this); }

    // Value
    std::vector<int>          intListValue() const {return _value;}
    bool                 setNewValue(const std::string& value);
    bool                 setValue(const std::vector<int>& value);
    int                  size() const;
    ParamType            getType() const {return Parameter::IntList;}
    const char*          getTypeName() const { return "int"; }

    // Default
    std::vector<int>          defaultValue() const {return _default;}
    bool                 setNewDefault(const std::string& value);
    bool                 setDefault(const std::vector<int>& value);
    void                 revertToDefault();

    // Fomatting
    std::string               asString() const;
    std::string               defaultAsString() const;

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.intListValue());}

    // Parsing
    bool parse(const std::string& str, std::vector<int>& value);

    // Validation
    bool isValid(const std::vector<int>& n) const;
    void reportRangeError(const std::string& valueString);

    // Member data
    std::vector<int>   _value;
    std::vector<int>   _default;
};

#endif
