/*****************************************************************************
 *
 *  ParameterInfo.h                             XMM Science Analysis Subsystem
 *
 *  Information about parameters of a task
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: ParameterInfo.h,v 1.15 2003/02/10 15:19:09 jbakker Exp $
 *
 *****************************************************************************/

#ifndef PARAMINFO_H
#define PARAMINFO_H

#include "Parameter.h"            // Application headers

#include <iostream>             // C++ headers
#include <string>
#include <list>
#include <vector>
#include <map>


//================================================================
//  Class ParameterInfo
//================================================================

class ParameterInfo
{
public:

    // Types
    typedef std::map<std::string, Parameter*, std::less<std::string> > ParamMap;

    // Constructors and destructors
    ParameterInfo();
    ParameterInfo(const ParameterInfo&);
    ~ParameterInfo();

    // Assignment operator
    ParameterInfo& operator=(const ParameterInfo& rhs);

    // Adding parameters
    void addParameter(Parameter* param, bool root=true);

    // Command line
    std::string asCommandLine() const;
    std::vector<std::string> asArgumentList() const;
    void parseCommandLine(int& argc, char** argv);

    // Task name
    std::string taskName() const { return _taskName; }
    void setTaskName(const std::string& name);

    // Accessors
    std::list<std::string> names() const; // all names
    std::list<std::string> rootNames() const; // root parameters
    Parameter* operator[](const std::string& name) const;
    Parameter* parameter(const std::string& name, bool alertError=false) const;

    // Defaults
    void revertToDefault();

    // Validation
    void checkMandatoryParameters();

    // Stream I/O
    friend std::ostream& operator<<(std::ostream& os, const ParameterInfo& p);
    void writeHelpToStream(std::ostream& os) const;

    

private:

    // Command line
    void parseSASCommandLine(int& argc, char** argv);
    void parsePCSCommandLine(int& argc, char** argv);

    void copy(const ParameterInfo& rhs);

    // Member data
    std::string       _taskName;
    mutable ParamMap     _map;
    std::list<std::string> _nameList;     // Ordered std::list of std::map keys
    std::list<std::string> _rootList;     // Ordered std::list of root parameters
};

#endif

