/*****************************************************************************
 *
 *  RealParameter.h                             XMM Science Analysis Subsystem
 *
 *  Real task parameter
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: RealParameter.h,v 1.14 2002/12/17 17:53:50 jbakker Exp $
 *
 *****************************************************************************/

#ifndef REALPARAMETER_H
#define REALPARAMETER_H

#include <iostream>             // C++ headers
#include "Parameter.h"


//================================================================
//  Class RealParameter
//================================================================

class RealParameter : public Parameter
{
public:
    // Construction
    RealParameter() : _value(0),_default(0) {}
    RealParameter* clone() { return new RealParameter(*this); }

    // Value
    double      realValue() const { return _value; }
    bool        setNewValue(const std::string& value);
    bool        setValue(double value);
    ParamType   getType() const {return Parameter::Real;}
    const char* getTypeName() const { return "real"; }

    // Default
    double     defaultValue() const {return _default;}
    bool       setNewDefault(const std::string& value);
    bool       setDefault(double value);
    void       revertToDefault();

    // Formatting
    std::string      asString() const;
    std::string     defaultAsString() const;

protected:
    // Parsing
    virtual bool parse(const std::string& str, double& value);

    // Member data
    double _value;
    double _default; 

private:
    // called by Parameter::setValue(const Parameter&);
    bool assignValueOf(const Parameter& p) {return setValue(p.realValue());}

    // Validation
    virtual bool isValid(double value) const;
    void reportRangeError(const std::string& valueString);
};

#endif
