/*****************************************************************************
 *
 *  XpiInfoReader.cc                            XMM Science Analysis Subsystem
 *
 *  Reader for XPI files
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *  (c) 2003  ESA  -  Reimplemented to use XpiParamParser by Jorgo Bakker, BSC
 *
 *  $Id: XpiInfoReader.cc,v 1.26 2003/02/10 15:19:09 jbakker Exp $
 *
 *****************************************************************************/

#include "XpiInfoReader.h"
#include "XpiParamParser.h"
#include "ParameterInfo.h"
#include <errstr.h>
#include <SasFileLocator.h>

XpiInfoReader::XpiInfoReader(const std::string& name,bool isTaskName)
{
  _info = 0;
  std::string parFile;
  if (isTaskName) {
      std::string parName("config/" + name + ".par");
      SasFileLocator locator("");
      parFile = locator.locate(parName, "", false);

      if (parFile.empty())
	errstr << "Could not find parameter file '"
	       << parName << "' in SAS_PATH or SAS_DIR"
	       << Sas::error("ParamFileOpen");
  }
  else {
    parFile=name;
  }

  // This replaces old code
  XpiParamParser parser;
  _info=parser.load(parFile);

  if (_info) _info->setTaskName(isTaskName?name:parFile);
}
    

XpiInfoReader::~XpiInfoReader()
{
}

/*** Return a new ParameterInfo; caller must delete ***/

ParameterInfo* XpiInfoReader::getParamInfo()
{
    return _info;   // Null pointer if error
}

