/****************************************************************************
 *
 *  testparamcc.cc                             XMM Science Analysis Subsystem
 *
 *  Test C++ API of param package
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: testparamcc.cc,v 1.10 2003/06/13 12:06:03 gvacanti Exp $
 *
 *****************************************************************************/

#include <Parameter.h>               // Application headers
#include <param.h>

#include <cmath>                    // C headers

#include <iostream>                // C++ headers
#include <string>

#include <errstr.h>
#include <cassert>

int main(int argc, char* argv[])
{
    const double epsilon = 1e-5;

    std::string taskname(argv[0]);
    errHandler.name(taskname);

    openParameters(taskname);
    gParameters->parseCommandLine(argc,argv);

    std::cout << std::endl << "Parameter info:" << std::endl 
	 << *gParameters << std::endl;


    /*** Boolean parameter ***/

    bool bval0   = booleanParameter("bval0");
    bool bval1   = booleanParameter("bval1");
    std::cout << "bval0  = " << bval0 << std::endl;
    std::cout << "bval1  = " << bval1 << std::endl;
    assert(bval0 == false);
    assert(bval1 == true);


    /*** Integer parameter ***/
    
    int ival    = intParameter("ival");
    std::cout << "ival   = " << ival << std::endl;
    assert(ival == 42);


    /*** Real parameter ***/

    double rval  = realParameter("rval");
    std::cout << "rval   = " << rval << std::endl;
    assert(fabs(rval - 1.23e-5) < 1.23e-5 * epsilon);


    /*** String parameter ***/

    std::string sval = stringParameter("sval");
    std::cout << "sval   = " << sval << std::endl;
    assert(sval == "ab #,cd");


    /*** Filename parameter ***/

    std::string fval = stringParameter("fval");
    std::cout << "fval   = " << fval << std::endl;
    assert(fval == "temp");


    /*** Boolean parameter std::list ***/

    int nblist = parameterCount("blist");
    assert(nblist == 3);
    for(int i=0; i<nblist; i++)
        std::cout << "blist[" << i << "] = " << booleanParameter("blist",i) << std::endl;
    assert(booleanParameter("blist",0) == true);
    assert(booleanParameter("blist",1) == true);
    assert(booleanParameter("blist",2) == false);


    /*** Integer parameter std::list ***/

    int nilist = parameterCount("ilist");
    assert(nilist == 3);
    for(int i=0; i<nilist; i++)
        std::cout << "ilist[" << i << "] = " << intParameter("ilist",i) << std::endl;
    assert(intParameter("ilist",0) ==  5);
    assert(intParameter("ilist",1) == 17);
    assert(intParameter("ilist",2) == -2);


    /*** Real parameter std::list ***/

    int nrlist = parameterCount("rlist");
    assert(nrlist == 2);
    for(int i=0; i<nrlist; i++)
        std::cout << "rlist[" << i << "] = " << realParameter("rlist",i) << std::endl;
    assert(fabs(realParameter("rlist",0) - -1.2e-3) < 1.2e-3 * epsilon);
    assert(fabs(realParameter("rlist",1) - 3.4e3) < 1e-2 * epsilon);


    /*** String parameter std::list ***/

    int nslist = parameterCount("slist");
    assert(nslist == 3);
    for(int i=0; i<nslist; i++)
      std::cout << "slist[" << i << "] = \"" 
	   << stringParameter("slist",i) << '"' << std::endl;
    assert(stringParameter("slist",0) == "ab,# cd");
    assert(stringParameter("slist",1) == "");
    assert(stringParameter("slist",2) == "ef");


    /*** Filename parameter std::list ***/

    int nflist = parameterCount("flist");
    assert(nflist == 2);
    for(int i=0; i<nflist; i++)
        std::cout << "flist[" << i << "] = " << stringParameter("flist",i) << std::endl;
    assert(stringParameter("flist",0) == "/tmp/t1");
    assert(stringParameter("flist",1) == "t2");


    /*** Boolean parameter std::list as STL std::vector ***/

    std::vector<int> bvect = boolListParameter("blist");
    assert(bvect.size() == 3);
    assert(bvect[0] == true);
    assert(bvect[1] == true);
    assert(bvect[2] == false);


    /*** Integer parameter std::list as STL std::vector ***/

    std::vector<int> ivect = intListParameter("ilist");
    assert(ivect.size() == 3);
    assert(ivect[0] ==  5);
    assert(ivect[1] == 17);
    assert(ivect[2] == -2);


    /*** Real parameter std::list as STL std::vector ***/

    std::vector<double> rvect = realListParameter("rlist");
    assert(rvect.size() == 2);
    assert(fabs(rvect[0] - -1.2e-3) < 1.2e-3 * epsilon);
    assert(fabs(rvect[1] - 3.4e3) < 1e-2 * epsilon);


    /*** String parameter std::list as STL std::vector ***/

    std::vector<std::string> svect = stringListParameter("slist");
    assert(svect.size() == 3);
    assert(svect[0] == "ab,# cd");
    assert(svect[1] == "");
    assert(svect[2] == "ef");


    std::cout << gParameters->asCommandLine() << std::endl;

    closeParameters();

    return 0;
}
